@@ -1,31 +1,26 @@
-/**
- *                                           ,@@@@@@@
-                                          #@@@@@@@@@
-                                           @@@@@@@@@
-                                            .@@@@@
-                                     ,@@@@@&
-                                    @@@@@@@@@
-                                  @@@@@@@ @@@@@
-                                @@@@@@@*    @@@@@
-                              @@@@@@@&       /@@@, /(((((((
-                            (*   @@@               ((((((((
-                         ((((((((                    ((((
-                         ((((((((  @&
-                           ((((  .@@@@@@@
-              @@@@@@@@@(         @@@@@@@@@@@             @@@@@@@@@@
-          @@@@@       *@@@@@          @@@@@@         @@@@@        @@@@@
-        @@@               &@@@        @@@@@@       @@@                @@@
-       @@@                  @@@       @@@@@@      @@@                  @@@
-      @@@                    @@&      @@@@@@     @@@                    @@@
-      @@&                    @@@       ((((      @@@                    @@@
-      @@@                    @@(     (((((((/    &@@                    @@(
-       @@@                  @@@      (((((((.     @@@                  @@@
-        *@@@             .@@@           .           @@@(            &@@@
-           @@@@@@@@@@@@@@@@                           %@@@@@@@@@@@@@@/
-                 *##.
- *
- *
- */
+/*
+Copyright (C) 2021 Velometrik GmbH
+<http://www.velometrik.de/>
+
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
+
+
+/* 
+    Created on : 04.06.2021, 21:08:29
+    Author     : Peter Bauer
+*/
 // const host = "http://velobox-peter.local:8080";
 hide_mask();
 
@@ -43,7 +38,6 @@ var onsqlresult = getLog;
 var jsn_result1 = new Object();
 var jsn_result2 = new Object();
 
-var log = false;
 var cable = false
 var showText = true;
 
@@ -55,32 +49,15 @@ let hocker_frame = `${host}/sattelbild?image=blank`;
 let setting = new Object();
 let galerie_image_info;
 var data;
-// if(localStorage.getItem('setting')===null){
-// setting.initial = true;
-// setting.bgColor = "#000000";
-// setting.mask = "nomask";
-// setting.aufZeit = 3;
-// setting.verZeit = 3;
-// // setting.contrast = "4";
-// setting.center_color="#ff0000";
-// setting.teil_color = "#ffffff";
-// setting.teil_line = true;
-// setting.text_color ="#ffffff";
-// setting.pr_color="#000000";
-// setting.line_color ="#ffff00";
-// setting.showText = true;
-// setting.pelv = 1
-// localStorage.setItem("setting",JSON.stringify(setting));
-// // sattelanalyse.send(`set clientsettings ${JSON.stringify(setting)}`)
-// } else {
-// // setting = JSON.parse(localStorage.getItem('setting'));
-// }
 
 let note = localStorage.getItem('session_note')
 
 var load_num;
 var querys;
 
+var bread=0
+
+
 document.getElementById('headliner').innerHTML = localStorage.getItem('client_name');
 
 // document.getElementById('product1').setAttribute('placeholder',gettrans('sda_marke'))
@@ -312,10 +289,6 @@ function set_comp(param) {
 function session (val){
       // console.log('session',val);
     sattelanalyse.send(`session ${val}`)
-    // sattelanalyse.send(`session start 1`)
-    // $('#client_name')[0].innerHTML = localStorage.getItem('client_name');
-    // $('#client_mail')[0].innerHTML = localStorage.getItem('client_mail');
-
     onsqlresult = Maskmenue;
     sattelanalyse.send(`sql select name from masks where mask_id > 4`);
 }
@@ -332,7 +305,8 @@ function save_rec(num) {
   info.notes = $(`#notes${num}`)[0].value;
   // console.log(`recording store ${num} ${JSON.stringify(info)}`);
   sattelanalyse.send(`recording store ${num} ${JSON.stringify(info)}`);
-  UIkit.notification({message: `Image ${num} saved`, status: 'success'})
+  //TODO: Dialog nach aktuellem CI erstellen und übersetzen!
+  UIkit.notification({message: `${aLangKeys[lang]['save_data']}`})
 }
 
 /**
@@ -344,14 +318,14 @@ function load_rec(num) {
   // console.log('load ',num);
   if(localStorage.getItem('session').split(' ')[0]=='restart'){
   onsqlresult = RowImg
-  sattelanalyse.send(`sql select * from recordings where session_id=${localStorage.getItem('session').split(' ')[1]}`)
+  sattelanalyse.send(`sql select * from recordings WHERE analysis=2 AND session_id=${localStorage.getItem('session').split(' ')[1]}`)
   }
   if(localStorage.getItem('session').split(' ')[0]=='start'){
    onsqlresult = getSession
    sattelanalyse.send(`sql SELECT next_id from nextids n WHERE table_name = 'sessions'`)
    let getrow = setInterval(function () {
     onsqlresult = RowImg
-    sattelanalyse.send(`sql select * from recordings where session_id=${localStorage.getItem('new_session')}`)
+    sattelanalyse.send(`sql select * from recordings WHERE analysis=2 AND session_id=${localStorage.getItem('new_session')}`)
     clearInterval(getrow);
   }, 1000);
   }
@@ -473,6 +447,8 @@ function run_Sattelanalyse() {
         } catch (error) {
           console.error(error);
         }
+        if(log)
+        console.log(data);
         if(data.wsevent ==="clientsettings"){
           setting = data.clientsettings
           if(setting.initial){
@@ -614,7 +590,6 @@ function run_Sattelanalyse() {
               }, 100);
              }
         }
-
         /* Setting the image to the canvas. */
         if (data.wsevent === "sda_int2") {
             sda_frame2 = `${host}/sattelbild?image=sda_int2&rnd=${(new Date).getTime()}`;
@@ -637,9 +612,9 @@ function run_Sattelanalyse() {
           img.src=sda_frame3
           a.setAttribute('onclick',`sattelanalyse.send('recording retrieve ${recID[fi-1]} ${load_num}')`)
           if(galerie_image_info.pelvisrotation)
-         pel = `${galerie_image_info.pelvisrotation.width||""}:${galerie_image_info.pelvisrotation.height||""}`
-         else
-         pel ="-"
+            pel = `${galerie_image_info.pelvisrotation.width||""}:${galerie_image_info.pelvisrotation.height||""}`
+          else
+            pel ="-"
          document.getElementsByClassName('info_img')[fi-1].innerHTML =`
          <ul class="uk-list uk-list-collapse">
          <li key="pro_satteldruck_veloscore">Veloscore</li>
@@ -688,6 +663,14 @@ function run_Sattelanalyse() {
             cop2.x = data.pelvisrotation.center.x;
             cop2.y = data.pelvisrotation.center.y;
             }
+            if(bread === 0){
+              let append = document.getElementById('menu_bread')
+              let li = newElement({element:'li'},append)
+              let a = newElement({element:'a',cls:['font-12'],attr:[['onclick','toProtokol()'],['key','pro_protokoll']]},li)
+              a.innerHTML = '<!--Protokoll-->'
+              translatejs();
+              bread++
+             }
         }
        /* Checking the state of the tty. */
         if (data.wsevent === "ttystate"){
@@ -735,22 +718,12 @@ function Maskmenue (params){
  */
 function add_mask(name){
   let append = $('#mask_list')
-  let e = document.createElement('li');
-  let div = document.createElement('div');
-  div.classList.add('uk-link-li')
-  div.id = name
-  let a = document.createElement('a');
-  let a2 = document.createElement('a');
-  a.href = "#modal-dialog";
-  a2.href = "#modal-dialog";
-  a.setAttribute('onclick',`set_mask("${name}")`);
-  a2.setAttribute('onclick',`del_mask("${name}")`);
+  let e = newElement({element:'li'},append)
+  let div = newElement({element:'div',cls:['mask_link'],id:`${name}`},e)
+  let a = newElement({element:'a',attr:[['href','#modal-dialog'],['onclick',`set_mask("${name}")`]]},div)
+  let a2 = newElement({element:'a',attr:[['onclick',`del_mask("${name}")`],['href','#modal-dialog']]},div)
+  let span = newElement({element:'span',cls:['ico-16','mdi','mdi-trash-can-outline']},a2)
   a.innerHTML = name
-  a2.innerHTML = '<span class="ico-16 mdi mdi-trash-can-outline"></span>'
-  append.append(e);
-  e.append(div)
-  div.append(a);
-  div.append(a2)
 }
 
 
@@ -821,7 +794,7 @@ function error_msg (jsn){
   //h2.innerHTML = `${jsn.class} - ERROR`;
   
   if(jsn.class == 'user'){
-    ico.setAttribute('uk-icon','icon: users; ratio: 1')
+    ico.setAttribute('uk-icon','icon: warning; ratio: 1')
   }
   if(jsn.class == 'client'){
     ico.setAttribute('uk-icon','icon: desktop; ratio: 1')
@@ -834,12 +807,13 @@ function error_msg (jsn){
     txt_num.setAttribute('key','err_bt_fail');
   }
 
-  txt.innerHTML = `MESSAGE: ${jsn.msg}`;
+  txt.innerHTML = `MESSAGE: ${jsn.msg} `;
+  
   if(jsn.source){
-    txt.innerHTML += `SOURCE: ${jsn.source}`
+    txt.innerHTML += `SOURCE: ${jsn.source} `
   }
   if(jsn.nr){
-    txt.innerHTML += `ERROR-CODE: ${jsn.nr}`
+    txt.innerHTML += `ERROR-CODE: ${jsn.nr} `
   }
   if(jsn.nr == 3){
     txt_num.setAttribute('key','err_num_3');
@@ -856,6 +830,8 @@ function error_msg (jsn){
 function sattel_einstellungen() {
   UIkit.modal($("#modal-einstellungen")).show();
 }
+var img_a1=0;
+var img_a2=0;
 /**
  * It takes a number as an argument, and then it uses that number to find the progress bar with the
  * same number in its id. Then it uses the value of the progress bar to determine how long it should
@@ -867,10 +843,19 @@ function ProgressTimeHandler(num) {
   const aufnahme = setting.aufZeit;// document.getElementById(`aufzeichnung`).value;
   const before = setting.verZeit; // document.getElementById(`time_before`).value;
   let lauf = true;
-  if(num===1)
+  if(num===1){
   jsn_result1= new Object();
-  if(num===2)
+  if(img_a1>0)
+    save_rec(1)
+  img_a1++
+  }
+  if(num===2){
   jsn_result2= new Object();
+  if(img_a2>0)
+    save_rec(2)
+  img_a2++
+  }
+  
   /* A progress bar that is used to show the user how much time is left until the next recording. */
   var ani = setInterval(()=>{
     if (lauf) {
@@ -1387,13 +1372,19 @@ if(z.pelvisrotation)
     border: 0
   });
   if(setting.showText){
-  drawtext(canvas,10,10,`left:right:`);
-  drawtext(canvas,10,30,`front:rear:`);
-  drawtext(canvas,10,50,`rotation:`);
-  drawtext(canvas,100,10,`${z.left_right}`);
-  drawtext(canvas,100,30,`${z.front_rear}`);
-  if(z.pelvisrotation)
-  drawtext(canvas,100,50,`${z.pelvisrotation.width}:${z.pelvisrotation.height}`);
+  let abstand = 0;
+  drawtext(canvas,10,10,`${aLangKeys[lang]['sda_leftright']}:`);
+  abstand=aLangKeys[lang]['sda_leftright'].length;
+  drawtext(canvas,10,30,`${aLangKeys[lang]['sda_frontrear']}:`);
+  if(aLangKeys[lang]['sda_frontrear']>abstand)
+  abstand=aLangKeys[lang]['sda_frontrear'].length;
+  abstand=abstand+120;
+  drawtext(canvas,abstand,10,`${z.left_right}`);
+  drawtext(canvas,abstand,30,`${z.front_rear}`);
+    if(z.pelvisrotation){
+    drawtext(canvas,10,50,`${aLangKeys[lang]['sda_rotation']}:`);
+    drawtext(canvas,abstand,50,`${z.pelvisrotation.width}:${z.pelvisrotation.height}`);
+    }
   }
   canvas.add(kreis);
   canvas.add(line);
@@ -1629,5 +1620,14 @@ function hideMask (num){
 
 $('document').ready(()=>{
     let comp = document.getElementsByClassName('switchery')
-      comp[0].setAttribute('style','background-color: #5cbc40;border-color: #5cbc40;box-shadow: #5cbc40 0px 0px 0px 11px inset;transition: border 0.4s ease 0s, box-shadow 0.4s ease 0s, background-color 1.2s ease 0s;')
-});
\ No newline at end of file
+      comp[0].setAttribute('style','background-color: var(--primary);border-color: var(--primary);box-shadow: var(--primary) 0px 0px 0px 11px inset;transition: border 0.4s ease 0s, box-shadow 0.4s ease 0s, background-color 1.2s ease 0s;')
+});
+
+function showErrormessage() {
+    let x = document.getElementById("error_p");
+    if (x.style.display === "none") {
+        x.style.display = "block";
+    } else {
+        x.style.display = "none";
+    }
+} 
\ No newline at end of file
