@@ -1,25 +1,31 @@
 /*
- * Copyright (C) 2022 Peter Bauer; Björn Bauer / Velometrik GmbH
- * <http://www.velometrik.de/>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+Copyright (C) 2021 Velometrik GmbH
+<http://www.velometrik.de/>
 
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
+
+
+/* 
+    Created on : 04.06.2021, 21:08:29
+    Author     : Peter Bauer
+*/
 var aLangKeys = new Object();
 var lang;
 var back = document.getElementsByClassName('right_col')[0];
 let menu_bread = document.getElementById('menu_bread');
+var log = localStorage.getItem('log') || false;
 
 var week = ["week_0","week_1","week_2","week_3","week_4","week_5","week_6"];
 var month = ["mon_0","mon_1","mon_2","mon_3","mon_4","mon_5","mon_6","mon_7","mon_8","mon_9","mon_10","mon_11"];
@@ -149,7 +155,7 @@ function langSelected(lang) {
  * It fetches the JSON file, then calls the _Translate function with the JSON file as an argument.
  */
 function translatejs() {
-  fetch("/production/localisation/lang.json", {
+  fetch("/production/localisation/lang.json?v=1", {
     mode: "no-cors",
   }) // disable CORS because path does not contain http(s)
     .then((res) => res.json())
@@ -267,7 +273,7 @@ function BreadCrumb(params) {
     var path = $('.meinpfad')[0];
     path.innerHTML = "";
     var ihome = document.createElement('i');
-    ihome.classList.add('fa','fa-sitemap')
+    ihome.classList.add('mdi','mdi-sitemap')
     var spanhome = document.createElement('span');
     // spanhome.classList.add('tr')
     spanhome.setAttribute('key','mainmenu_home');
@@ -276,7 +282,7 @@ function BreadCrumb(params) {
     path.append(spanhome);
     params.forEach(element => {
       var i = document.createElement('i');
-      i.classList.add('fa','fa-angle-right');
+      i.classList.add('mdi','mdi-menu-right');
       path.append(i);
       var s = document.createElement('span');
       // s.classList.add('tr');
@@ -293,9 +299,9 @@ function BreadCrumb(params) {
         a.setAttribute('href',`/production/${element}.tcls`)
         a.id = element.replaceAll(' ','')
         a.innerHTML = element
-        if(location.pathname == "/production/dashboard.tcls"){
-         li.classList.add('hidden')
-        }
+        //if(location.pathname == "/production/dashboard.tcls"){
+        // li.classList.add('hidden')
+        //}
         if(element==='client'){
           a.removeAttribute('key');
           a.innerHTML = localStorage.getItem('client_name')
@@ -403,12 +409,16 @@ if(location.pathname == "/production/sitzknochenvermessung.tcls"){
 if(location.pathname == "/production/wlanconfig.tcls"){
   BreadCrumb(['dashboard','wlanconfig'])
 }
+if(location.pathname == "/production/changelog.tcls"){
+  BreadCrumb(['dashboard','changelog'])
+}
 
 var checkbox = document.getElementById('basic');
 var checkbox_view = document.getElementById('switch-1')
 var checkbox_mask1 = document.getElementById('mask1')
 var checkbox_mask2 = document.getElementById('mask2')
 var checkbox_set_comp = document.getElementById('set_comp')
+var checkbox_maskedit = document.getElementById('maskedit');
 
 function chk_wifi() {
 //ETH-CONN
@@ -474,6 +484,7 @@ $(document).ready(function () {
   if(location.pathname == "/production/new_satteldruckanalyse.tcls"){
     checkbox_mask1.removeAttribute('checked')
     checkbox_mask2.removeAttribute('checked')
+    checkbox_maskedit.removeAttribute('checked')
   }
 });
 
@@ -522,6 +533,21 @@ try {
   // console.log(error);
 }
 
+try {
+  checkbox_maskedit.addEventListener('change', function() {
+    console.log(this.dataset.num);
+    if (this.checked) {
+      document.getElementById("maskedit").nextSibling.classList.add('custom_switch')
+      hide_mask()
+    } else {
+      document.getElementById("maskedit").nextSibling.classList.remove('custom_switch')
+      hide_mask()
+    }
+});
+} catch (error) {
+  
+}
+
 try {
   checkbox_set_comp.addEventListener('change', function() {
     console.log(this.dataset.num);
@@ -609,26 +635,37 @@ let clock_dash = setInterval(function () {
 
 /**
  * It creates a new element with the given parameters and appends it to the given element
- * @param params - {
- * @param append - The element to append the new element to.
- * @returns The element that was created.
+ * 
+ * @function
+ * @name newElement
+ * @kind function
+ * @param {Object<JSON>} jsn - JSON object
+ * @param {String} jsn.element    - HTML element name
+ * @param {String} jsn.id    - ID of the element
+ * @param {Array<String>} jsn.cls - classes of the element
+ * @param {Array<Array<String>>} jsn.attr - Attriburtes of the HTML element
+ * @param {HTMLElement} DOM_Element - the complete element
+ * @returns {HTMLElement} 
  */
-function newElement(params,append) {
-  let e = document.createElement(params.element)
-  if(params.cls){
-      params.cls.forEach(element => {
+function newElement(jsn, DOM_Element) {
+  let e = document.createElement(jsn.element)
+  if(jsn.cls){
+      jsn.cls.forEach(element => {
           e.classList.add(element)            
       });
   }
-  if(params.id){
-      e.id = params.id
+  if(jsn.id){
+      e.id = jsn.id
   }
-  if(params.attr){
-      params.attr.forEach(element=>{
+  if(jsn.attr){
+      jsn.attr.forEach(element=>{
           e.setAttribute(element[0],element[1])
       });
   }
-  append.append(e)
+  if(log){
+    console.log('newElement',e);
+  }
+  DOM_Element.append(e)
   return e;
 }
 
@@ -648,7 +685,7 @@ function CreateReadMeMod(params) {
   // ModalH2.innerHTML= aLangKeys[lang][params]
   let ModalReadmeText1 = newElement({element:'p'},ModalBody);
 
-  fetch(`/production/manuals/${lang}/${params}.html`, {
+  fetch(`/production/manuals/${lang}/${params}.html?v=1`, {
     mode: "no-cors",
   }) // disable CORS because path does not contain http(s)
     .then((res) => res.text())
@@ -662,4 +699,14 @@ function CreateReadMeMod(params) {
 // OpenReadMe
 function OpenReadMe(params) {
   UIkit.modal(`#mod_${params}`).show();
-}
\ No newline at end of file
+}
+
+if(location.pathname == '/production/sitzknochenvermessung.tcls'){
+  var menueintrag = document.getElementById('sitzknochenvermessung');
+  menueintrag.classList.add('hidden');
+}
+
+function openWindow() {
+  window.open(`${location.origin}`, "NewWindow",`toolbar=no,menubar=no,scrollbars=no,fullscreen=yes,width=${screen.width},height=${screen.height}`)
+  this.close()
+}
